--------------------------------------------------
--   N A M E S P A C E    D E F I N I T I O N   --
--------------------------------------------------
EBRA = {};


--------------------------------------------------
-- P R I V A T E / L O C A L  V A R I A B L E S --
--------------------------------------------------


--------------------------------------------------
-- P R I V A T E / L O C A L  F U N C T I O N S --
--------------------------------------------------


--------------------------------------------------
-- P U B L I C / G L O B A L  F U N C T I O N S --
--------------------------------------------------

-- Receive the remaining Time of a Debuff.
-- @param 'tarID' ID of the Player for which we want to get the remaining Debuff Time.
-- @param 'abilityId' ID of the Debuff.
-- @return A floating Number storing the remaining Time of a specific Debuff.
-- @example EBRA.getRemainingDebuffTime("focus", 197943) returns the remaining Overwhelm-Debuff Time of the Focus-Target.
function EBRA.getRemainingDebuffTime(tarID, abilityId)

  local result = 0;
  
  -- Loop through all Debuffs
  for i=1,40,1 do
    local _, _, _, _, _, _, expirationTime, _, _, _, spellId = UnitDebuff(tarID, i); 
    
    -- Error Check. Nil Values should be handled
    if expirationTime ~= nil and spellId ~= nil then
      -- Target has the specific Debuff
      if spellId == abilityId then
        result = expirationTime - GetTime();  
      end
    end
  end
  
  -- Handle negative Numbers
  if result >= 0 then
    return result;
  else
    return 0;
  end
end


-- Receive the Stack Count of a specific Debuff.
-- @param 'tarID' ID of the Player for which we want to get the remaining Debuff Time.
-- @param 'abilityId' ID of the Debuff.
-- @return A integer Number storing the Debuff Stack Count.
function EBRA.getDebuffStack(tarID, abilityId)

  local result = 0;
  
  -- Loop through all Debuffs
  for i=1,40,1 do
    local _, _, _, count, _, _, _, _, _, _, spellId = UnitDebuff(tarID, i); 
    
    -- Error Check. Nil Values should be handled
    if count ~= nil and spellId ~= nil then
      -- Target has the specific Debuff
      if spellId == abilityId then
        result = count;  
      end
    end
  end
  
  -- Handle negative Numbers
  return result;
end


-- Returns whether the Player is Leader or Assist of the (Raid) Group.
-- @return 'true' iff the Player is Assist or Leader.
function EBRA.isAssist()
  local _, rank, _, _, _, _, _, _, _, _, _ = GetRaidRosterInfo( UnitInRaid("player") );

  if rank == 1 or rank == 2 then
    return true;
  else
    return false;
  end
end


-- Returns whether the Language of the Player's Client is English.
-- @return 'true' iff the Language is English.
-- @example EBRA.isClientLanguageEnglish() returns 'true' for English Clients.
function EBRA.isClientLanguageEnglish()
  if GetLocale() == "enGB" or GetLocale() == "enUS" then
    return true;
  else
    return false;
  end
end


-- Returns whether the Language of the Player's Client is German.
-- @return 'true' iff the Language is German.
-- @example EBRA.isClientLanguageGerman() returns 'true' for German Clients.
function EBRA.isClientLanguageGerman()
  if GetLocale() == "deDE" then
    return true;
  else
    return false;
  end
end


-- Checks whether a specific Player has the DD-Role assigned.
-- @param 'playerID' ID of the Player which should be checked.
-- @return True iff the specific Player is a DD.
-- @example EBRA.isDD("player") returns true iff the current Player is a DD.
function EBRA.isDD(playerID)
  local role = UnitGroupRolesAssigned(playerID);
  
  if role == "DAMAGER" then
    return true;
  else
    return false;
  end 
end


-- Checks whether a specific Player has the Heal-Role assigned.
-- @param 'playerID' ID of the Player which should be checked.
-- @return True iff the specific Player is a Healer.
-- @example EBRA.isHeal("player") returns true iff the current Player is a Healer.
function EBRA.isHeal(playerID)
  local role = UnitGroupRolesAssigned(playerID);
  
  if role == "HEALER" then
    return true;
  else
    return false;
  end 
end


-- Checks whether a specific Player has the Tank-Role assigned.
-- @param 'playerID' ID of the Player which should be checked.
-- @return True iff the specific Player is a Tank.
-- @example EBRA.isTank("player") returns true iff the current Player is a Tank.
function EBRA.isTank(playerID)
  local role = UnitGroupRolesAssigned(playerID);
  
  if role == "TANK" then
    return true;
  else
    return false;
  end 
end


-- Checks whether a specific Player is the Target of another specific Target.
-- @param 'playerID' ID of the Player for which is going to be checked to be the Target of 'targetID'.
-- @param 'targetID' ID of the Target which is checked for targeting the 'playerID'.
-- @example EBRA.isTarget("player", "targettarget") checks whether the Target of the current Player is targeting himself.
function EBRA.isTarget(playerID, targetID)
  local tName = UnitName(targetID);
  local pName = UnitName(playerID);
  
  if tName ~= nil and pName ~= nil and tName == pName then
    return true;
  else
    return false;
  end
end


-- Plays a specific Sound-File.
-- @param 'soundFile' Defines the Path to a specific Sound-File 
-- @param 'pauseTime' The Time before the Sound can be played again.
-- @example 
local lLastSound = 0;
local lInitSound = false;

function EBRA.playSound(soundFile, pauseTime)
  -- Initialize.
  if lInitSound == false then
    lLastSound = GetTime();
    lInitSound = true;
  end

  -- Play the Sound-File.
  if GetTime() - lLastSound >= pauseTime then 
    PlaySoundFile("interface\\addons\\EbonBladeRaidAssist\\Resources\\taunt.mp3", "Master");
    lLastSound = GetTime();
  end
end
 

--------------------------------------------------
--        E N D       O F     F I L E           --
--------------------------------------------------
return EBRA;